# MedCalc Package

A Python package containing implementations of various medical calculators.

This package provides functions for various medical calculations based on the work found in the MedCalc-Bench repository.

Homepage: [https://github.com/ncbi-nlp/MedCalc-Bench](https://github.com/ncbi-nlp/MedCalc-Bench)

## Installation

```bash
# Installation instructions will be added once the package is uploaded to PyPI
pip install medcalc-bench
```

## Usage

```python
# import medcalc.compute_fena
``` 